[evolution-data-server/wip/mcrha/libical-glib] Prefix some of the calendar defines with E_



commit 76c75935d940a73b5ceb66654414c271246a001b
Author: Milan Crha <mcrha redhat com>
Date:   Fri Jan 11 10:29:16 2019 +0100

    Prefix some of the calendar defines with E_
    
    To have them share the same namespace in introspection.

 .../backends/caldav/e-cal-backend-caldav.c         |  24 ++---
 .../backends/contacts/e-cal-backend-contacts.c     |   6 +-
 src/calendar/backends/file/e-cal-backend-file.c    |  32 +++----
 .../backends/gtasks/e-cal-backend-gtasks.c         |  12 +--
 .../backends/weather/e-cal-backend-weather.c       |  22 ++---
 src/calendar/libecal/e-cal-client.c                |  32 +++----
 src/calendar/libecal/e-cal-client.h                |  16 ++--
 src/calendar/libecal/e-cal-util.h                  | 106 ++++++++++-----------
 src/calendar/libecal/e-reminder-watcher.c          |   2 +-
 src/calendar/libedata-cal/e-cal-meta-backend.c     |  16 ++--
 src/calendar/libedata-cal/e-data-cal.c             |  12 +--
 .../evolution-alarm-notify/e-alarm-notify.c        |   2 +-
 tests/libedata-cal/test-cal-meta-backend.c         |   4 +-
 13 files changed, 143 insertions(+), 143 deletions(-)
---
diff --git a/src/calendar/backends/caldav/e-cal-backend-caldav.c 
b/src/calendar/backends/caldav/e-cal-backend-caldav.c
index f514ade73..cee04ed50 100644
--- a/src/calendar/backends/caldav/e-cal-backend-caldav.c
+++ b/src/calendar/backends/caldav/e-cal-backend-caldav.c
@@ -2041,16 +2041,16 @@ ecb_caldav_get_backend_property (ECalBackend *backend,
                gchar *usermail;
 
                caps = g_string_new (
-                       CAL_STATIC_CAPABILITY_NO_THISANDPRIOR ","
-                       CAL_STATIC_CAPABILITY_REFRESH_SUPPORTED ","
-                       CAL_STATIC_CAPABILITY_TASK_CAN_RECUR ","
-                       CAL_STATIC_CAPABILITY_COMPONENT_COLOR);
+                       E_CAL_STATIC_CAPABILITY_NO_THISANDPRIOR ","
+                       E_CAL_STATIC_CAPABILITY_REFRESH_SUPPORTED ","
+                       E_CAL_STATIC_CAPABILITY_TASK_CAN_RECUR ","
+                       E_CAL_STATIC_CAPABILITY_COMPONENT_COLOR);
                g_string_append (caps, ",");
                g_string_append (caps, e_cal_meta_backend_get_capabilities (E_CAL_META_BACKEND (backend)));
 
                usermail = ecb_caldav_get_usermail (cbdav);
                if (!usermail || !*usermail)
-                       g_string_append (caps, "," CAL_STATIC_CAPABILITY_NO_EMAIL_ALARMS);
+                       g_string_append (caps, "," E_CAL_STATIC_CAPABILITY_NO_EMAIL_ALARMS);
                g_free (usermail);
 
                source = e_backend_get_source (E_BACKEND (backend));
@@ -2059,13 +2059,13 @@ ecb_caldav_get_backend_property (ECalBackend *backend,
                if (e_source_webdav_get_calendar_auto_schedule (extension)) {
                        g_string_append (
                                caps,
-                               "," CAL_STATIC_CAPABILITY_CREATE_MESSAGES
-                               "," CAL_STATIC_CAPABILITY_SAVE_SCHEDULES);
+                               "," E_CAL_STATIC_CAPABILITY_CREATE_MESSAGES
+                               "," E_CAL_STATIC_CAPABILITY_SAVE_SCHEDULES);
                }
 
                return g_string_free (caps, FALSE);
-       } else if (g_str_equal (prop_name, CAL_BACKEND_PROPERTY_CAL_EMAIL_ADDRESS) ||
-                  g_str_equal (prop_name, CAL_BACKEND_PROPERTY_ALARM_EMAIL_ADDRESS)) {
+       } else if (g_str_equal (prop_name, E_CAL_BACKEND_PROPERTY_CAL_EMAIL_ADDRESS) ||
+                  g_str_equal (prop_name, E_CAL_BACKEND_PROPERTY_ALARM_EMAIL_ADDRESS)) {
                return ecb_caldav_get_usermail (E_CAL_BACKEND_CALDAV (backend));
        }
 
@@ -2098,9 +2098,9 @@ ecb_caldav_notify_property_changed_cb (GObject *object,
        }
 
        if (email_address_changed) {
-               value = ecb_caldav_get_backend_property (cal_backend, CAL_BACKEND_PROPERTY_CAL_EMAIL_ADDRESS);
-               e_cal_backend_notify_property_changed (cal_backend, CAL_BACKEND_PROPERTY_CAL_EMAIL_ADDRESS, 
value);
-               e_cal_backend_notify_property_changed (cal_backend, CAL_BACKEND_PROPERTY_ALARM_EMAIL_ADDRESS, 
value);
+               value = ecb_caldav_get_backend_property (cal_backend, 
E_CAL_BACKEND_PROPERTY_CAL_EMAIL_ADDRESS);
+               e_cal_backend_notify_property_changed (cal_backend, E_CAL_BACKEND_PROPERTY_CAL_EMAIL_ADDRESS, 
value);
+               e_cal_backend_notify_property_changed (cal_backend, 
E_CAL_BACKEND_PROPERTY_ALARM_EMAIL_ADDRESS, value);
                g_free (value);
        }
 }
diff --git a/src/calendar/backends/contacts/e-cal-backend-contacts.c 
b/src/calendar/backends/contacts/e-cal-backend-contacts.c
index c91079fba..01b32cca2 100644
--- a/src/calendar/backends/contacts/e-cal-backend-contacts.c
+++ b/src/calendar/backends/contacts/e-cal-backend-contacts.c
@@ -1045,14 +1045,14 @@ e_cal_backend_contacts_get_backend_property (ECalBackend *backend,
        if (g_str_equal (prop_name, CLIENT_BACKEND_PROPERTY_CAPABILITIES)) {
                return NULL;
 
-       } else if (g_str_equal (prop_name, CAL_BACKEND_PROPERTY_CAL_EMAIL_ADDRESS) ||
-                  g_str_equal (prop_name, CAL_BACKEND_PROPERTY_ALARM_EMAIL_ADDRESS)) {
+       } else if (g_str_equal (prop_name, E_CAL_BACKEND_PROPERTY_CAL_EMAIL_ADDRESS) ||
+                  g_str_equal (prop_name, E_CAL_BACKEND_PROPERTY_ALARM_EMAIL_ADDRESS)) {
                /* A contact backend has no particular email address associated
                 * with it (although that would be a useful feature some day).
                 */
                return NULL;
 
-       } else if (g_str_equal (prop_name, CAL_BACKEND_PROPERTY_DEFAULT_OBJECT)) {
+       } else if (g_str_equal (prop_name, E_CAL_BACKEND_PROPERTY_DEFAULT_OBJECT)) {
                return NULL;
        }
 
diff --git a/src/calendar/backends/file/e-cal-backend-file.c b/src/calendar/backends/file/e-cal-backend-file.c
index b5103ae3b..86fd3bf9d 100644
--- a/src/calendar/backends/file/e-cal-backend-file.c
+++ b/src/calendar/backends/file/e-cal-backend-file.c
@@ -456,7 +456,7 @@ bump_revision (ECalBackendFile *cbfile)
        icalproperty_set_x (prop, revision);
 
        e_cal_backend_notify_property_changed (E_CAL_BACKEND (cbfile),
-                                             CAL_BACKEND_PROPERTY_REVISION,
+                                             E_CAL_BACKEND_PROPERTY_REVISION,
                                              revision);
 
        g_free (revision);
@@ -474,26 +474,26 @@ e_cal_backend_file_get_backend_property (ECalBackend *backend,
        if (g_str_equal (prop_name, CLIENT_BACKEND_PROPERTY_CAPABILITIES)) {
                return g_strjoin (
                        ",",
-                       CAL_STATIC_CAPABILITY_NO_EMAIL_ALARMS,
-                       CAL_STATIC_CAPABILITY_NO_THISANDPRIOR,
-                       CAL_STATIC_CAPABILITY_DELEGATE_SUPPORTED,
-                       CAL_STATIC_CAPABILITY_REMOVE_ONLY_THIS,
-                       CAL_STATIC_CAPABILITY_BULK_ADDS,
-                       CAL_STATIC_CAPABILITY_BULK_MODIFIES,
-                       CAL_STATIC_CAPABILITY_BULK_REMOVES,
-                       CAL_STATIC_CAPABILITY_ALARM_DESCRIPTION,
-                       CAL_STATIC_CAPABILITY_TASK_CAN_RECUR,
-                       CAL_STATIC_CAPABILITY_COMPONENT_COLOR,
+                       E_CAL_STATIC_CAPABILITY_NO_EMAIL_ALARMS,
+                       E_CAL_STATIC_CAPABILITY_NO_THISANDPRIOR,
+                       E_CAL_STATIC_CAPABILITY_DELEGATE_SUPPORTED,
+                       E_CAL_STATIC_CAPABILITY_REMOVE_ONLY_THIS,
+                       E_CAL_STATIC_CAPABILITY_BULK_ADDS,
+                       E_CAL_STATIC_CAPABILITY_BULK_MODIFIES,
+                       E_CAL_STATIC_CAPABILITY_BULK_REMOVES,
+                       E_CAL_STATIC_CAPABILITY_ALARM_DESCRIPTION,
+                       E_CAL_STATIC_CAPABILITY_TASK_CAN_RECUR,
+                       E_CAL_STATIC_CAPABILITY_COMPONENT_COLOR,
                        NULL);
 
-       } else if (g_str_equal (prop_name, CAL_BACKEND_PROPERTY_CAL_EMAIL_ADDRESS) ||
-                  g_str_equal (prop_name, CAL_BACKEND_PROPERTY_ALARM_EMAIL_ADDRESS)) {
+       } else if (g_str_equal (prop_name, E_CAL_BACKEND_PROPERTY_CAL_EMAIL_ADDRESS) ||
+                  g_str_equal (prop_name, E_CAL_BACKEND_PROPERTY_ALARM_EMAIL_ADDRESS)) {
                /* A file backend has no particular email address associated
                 * with it (although that would be a useful feature some day).
                 */
                return NULL;
 
-       } else if (g_str_equal (prop_name, CAL_BACKEND_PROPERTY_DEFAULT_OBJECT)) {
+       } else if (g_str_equal (prop_name, E_CAL_BACKEND_PROPERTY_DEFAULT_OBJECT)) {
                ECalComponent *comp;
                gchar *prop_value;
 
@@ -520,7 +520,7 @@ e_cal_backend_file_get_backend_property (ECalBackend *backend,
 
                return prop_value;
 
-       } else if (g_str_equal (prop_name, CAL_BACKEND_PROPERTY_REVISION)) {
+       } else if (g_str_equal (prop_name, E_CAL_BACKEND_PROPERTY_REVISION)) {
                icalproperty *prop;
                const gchar *revision = NULL;
 
@@ -1102,7 +1102,7 @@ cal_backend_file_take_icalcomp (ECalBackendFile *cbfile,
 
        e_cal_backend_notify_property_changed (
                E_CAL_BACKEND (cbfile),
-               CAL_BACKEND_PROPERTY_REVISION,
+               E_CAL_BACKEND_PROPERTY_REVISION,
                icalproperty_get_x (prop));
 }
 
diff --git a/src/calendar/backends/gtasks/e-cal-backend-gtasks.c 
b/src/calendar/backends/gtasks/e-cal-backend-gtasks.c
index 62adfd8d2..cc519a8da 100644
--- a/src/calendar/backends/gtasks/e-cal-backend-gtasks.c
+++ b/src/calendar/backends/gtasks/e-cal-backend-gtasks.c
@@ -438,14 +438,14 @@ ecb_gtasks_get_backend_property (ECalBackend *cal_backend,
 
        if (g_str_equal (prop_name, CLIENT_BACKEND_PROPERTY_CAPABILITIES)) {
                return g_strjoin (",",
-                       CAL_STATIC_CAPABILITY_NO_THISANDFUTURE,
-                       CAL_STATIC_CAPABILITY_NO_THISANDPRIOR,
-                       CAL_STATIC_CAPABILITY_TASK_DATE_ONLY,
-                       CAL_STATIC_CAPABILITY_TASK_NO_ALARM,
+                       E_CAL_STATIC_CAPABILITY_NO_THISANDFUTURE,
+                       E_CAL_STATIC_CAPABILITY_NO_THISANDPRIOR,
+                       E_CAL_STATIC_CAPABILITY_TASK_DATE_ONLY,
+                       E_CAL_STATIC_CAPABILITY_TASK_NO_ALARM,
                        e_cal_meta_backend_get_capabilities (E_CAL_META_BACKEND (cal_backend)),
                        NULL);
-       } else if (g_str_equal (prop_name, CAL_BACKEND_PROPERTY_CAL_EMAIL_ADDRESS) ||
-                  g_str_equal (prop_name, CAL_BACKEND_PROPERTY_ALARM_EMAIL_ADDRESS)) {
+       } else if (g_str_equal (prop_name, E_CAL_BACKEND_PROPERTY_CAL_EMAIL_ADDRESS) ||
+                  g_str_equal (prop_name, E_CAL_BACKEND_PROPERTY_ALARM_EMAIL_ADDRESS)) {
                ESourceAuthentication *authentication;
                ESource *source;
                const gchar *user;
diff --git a/src/calendar/backends/weather/e-cal-backend-weather.c 
b/src/calendar/backends/weather/e-cal-backend-weather.c
index 3fdd9f35c..48e614bad 100644
--- a/src/calendar/backends/weather/e-cal-backend-weather.c
+++ b/src/calendar/backends/weather/e-cal-backend-weather.c
@@ -635,22 +635,22 @@ e_cal_backend_weather_get_backend_property (ECalBackend *backend,
        if (g_str_equal (prop_name, CLIENT_BACKEND_PROPERTY_CAPABILITIES)) {
                return g_strjoin (
                        ","
-                       CAL_STATIC_CAPABILITY_NO_ALARM_REPEAT,
-                       CAL_STATIC_CAPABILITY_NO_AUDIO_ALARMS,
-                       CAL_STATIC_CAPABILITY_NO_DISPLAY_ALARMS,
-                       CAL_STATIC_CAPABILITY_NO_PROCEDURE_ALARMS,
-                       CAL_STATIC_CAPABILITY_NO_TASK_ASSIGNMENT,
-                       CAL_STATIC_CAPABILITY_NO_THISANDFUTURE,
-                       CAL_STATIC_CAPABILITY_NO_THISANDPRIOR,
-                       CAL_STATIC_CAPABILITY_REFRESH_SUPPORTED,
+                       E_CAL_STATIC_CAPABILITY_NO_ALARM_REPEAT,
+                       E_CAL_STATIC_CAPABILITY_NO_AUDIO_ALARMS,
+                       E_CAL_STATIC_CAPABILITY_NO_DISPLAY_ALARMS,
+                       E_CAL_STATIC_CAPABILITY_NO_PROCEDURE_ALARMS,
+                       E_CAL_STATIC_CAPABILITY_NO_TASK_ASSIGNMENT,
+                       E_CAL_STATIC_CAPABILITY_NO_THISANDFUTURE,
+                       E_CAL_STATIC_CAPABILITY_NO_THISANDPRIOR,
+                       E_CAL_STATIC_CAPABILITY_REFRESH_SUPPORTED,
                        NULL);
 
-       } else if (g_str_equal (prop_name, CAL_BACKEND_PROPERTY_CAL_EMAIL_ADDRESS) ||
-                  g_str_equal (prop_name, CAL_BACKEND_PROPERTY_ALARM_EMAIL_ADDRESS)) {
+       } else if (g_str_equal (prop_name, E_CAL_BACKEND_PROPERTY_CAL_EMAIL_ADDRESS) ||
+                  g_str_equal (prop_name, E_CAL_BACKEND_PROPERTY_ALARM_EMAIL_ADDRESS)) {
                /* Weather has no particular email addresses associated with it */
                return NULL;
 
-       } else if (g_str_equal (prop_name, CAL_BACKEND_PROPERTY_DEFAULT_OBJECT)) {
+       } else if (g_str_equal (prop_name, E_CAL_BACKEND_PROPERTY_DEFAULT_OBJECT)) {
                return NULL;
        }
 
diff --git a/src/calendar/libecal/e-cal-client.h b/src/calendar/libecal/e-cal-client.h
index 0fdd5bf3f..a0bcc8782 100644
--- a/src/calendar/libecal/e-cal-client.h
+++ b/src/calendar/libecal/e-cal-client.h
@@ -51,35 +51,35 @@
        ((obj), E_TYPE_CAL_CLIENT, ECalClientClass))
 
 /**
- * CAL_BACKEND_PROPERTY_CAL_EMAIL_ADDRESS:
+ * E_CAL_BACKEND_PROPERTY_CAL_EMAIL_ADDRESS:
  *
  * An email address associated with the calendar.
  *
  * Since: 3.2
  **/
-#define CAL_BACKEND_PROPERTY_CAL_EMAIL_ADDRESS         "cal-email-address"
+#define E_CAL_BACKEND_PROPERTY_CAL_EMAIL_ADDRESS       "cal-email-address"
 
 /**
- * CAL_BACKEND_PROPERTY_ALARM_EMAIL_ADDRESS:
+ * E_CAL_BACKEND_PROPERTY_ALARM_EMAIL_ADDRESS:
  *
  * An email address preferred for e-mail reminders by the calendar.
  *
  * Since: 3.2
  **/
-#define CAL_BACKEND_PROPERTY_ALARM_EMAIL_ADDRESS       "alarm-email-address"
+#define E_CAL_BACKEND_PROPERTY_ALARM_EMAIL_ADDRESS     "alarm-email-address"
 
 /**
- * CAL_BACKEND_PROPERTY_DEFAULT_OBJECT:
+ * E_CAL_BACKEND_PROPERTY_DEFAULT_OBJECT:
  *
  * A default object for the calendar. Calendars use VEVENT, memo lists VJOURNAL
  * and task lists VTODO, which can have prefilled values by the backend.
  *
  * Since: 3.2
  **/
-#define CAL_BACKEND_PROPERTY_DEFAULT_OBJECT            "default-object"
+#define E_CAL_BACKEND_PROPERTY_DEFAULT_OBJECT          "default-object"
 
 /**
- * CAL_BACKEND_PROPERTY_REVISION:
+ * E_CAL_BACKEND_PROPERTY_REVISION:
  *
  * The current overall revision string, this can be used as
  * a quick check to see if data has changed at all since the
@@ -87,7 +87,7 @@
  *
  * Since: 3.4
  **/
-#define CAL_BACKEND_PROPERTY_REVISION                  "revision"
+#define E_CAL_BACKEND_PROPERTY_REVISION                        "revision"
 
 /**
  * E_CAL_CLIENT_ERROR:
diff --git a/src/calendar/libecal/e-cal-util.h b/src/calendar/libecal/e-cal-util.h
index f1327ef73..6f41853ad 100644
--- a/src/calendar/libecal/e-cal-util.h
+++ b/src/calendar/libecal/e-cal-util.h
@@ -102,122 +102,122 @@ gboolean        e_cal_util_event_dates_match    (icalcomponent *icalcomp1,
                                                 icalcomponent *icalcomp2);
 
 /* The static capabilities to be supported by backends */
-#define CAL_STATIC_CAPABILITY_NO_ALARM_REPEAT          "no-alarm-repeat"
-#define CAL_STATIC_CAPABILITY_NO_AUDIO_ALARMS          "no-audio-alarms"
-#define CAL_STATIC_CAPABILITY_NO_DISPLAY_ALARMS                "no-display-alarms"
-#define CAL_STATIC_CAPABILITY_NO_EMAIL_ALARMS          "no-email-alarms"
-#define CAL_STATIC_CAPABILITY_NO_PROCEDURE_ALARMS      "no-procedure-alarms"
-#define CAL_STATIC_CAPABILITY_NO_TASK_ASSIGNMENT       "no-task-assignment"
-#define CAL_STATIC_CAPABILITY_NO_THISANDFUTURE         "no-thisandfuture"
-#define CAL_STATIC_CAPABILITY_NO_THISANDPRIOR          "no-thisandprior"
-#define CAL_STATIC_CAPABILITY_NO_TRANSPARENCY          "no-transparency"
+#define E_CAL_STATIC_CAPABILITY_NO_ALARM_REPEAT                "no-alarm-repeat"
+#define E_CAL_STATIC_CAPABILITY_NO_AUDIO_ALARMS                "no-audio-alarms"
+#define E_CAL_STATIC_CAPABILITY_NO_DISPLAY_ALARMS      "no-display-alarms"
+#define E_CAL_STATIC_CAPABILITY_NO_EMAIL_ALARMS                "no-email-alarms"
+#define E_CAL_STATIC_CAPABILITY_NO_PROCEDURE_ALARMS    "no-procedure-alarms"
+#define E_CAL_STATIC_CAPABILITY_NO_TASK_ASSIGNMENT     "no-task-assignment"
+#define E_CAL_STATIC_CAPABILITY_NO_THISANDFUTURE       "no-thisandfuture"
+#define E_CAL_STATIC_CAPABILITY_NO_THISANDPRIOR                "no-thisandprior"
+#define E_CAL_STATIC_CAPABILITY_NO_TRANSPARENCY                "no-transparency"
 
 /**
- * CAL_STATIC_CAPABILITY_MEMO_START_DATE:
+ * E_CAL_STATIC_CAPABILITY_MEMO_START_DATE:
  *
  * Flag indicating that the backend does not support memo's start date
  *
  * Since: 3.12
  */
-#define CAL_STATIC_CAPABILITY_NO_MEMO_START_DATE       "no-memo-start-date"
+#define E_CAL_STATIC_CAPABILITY_NO_MEMO_START_DATE     "no-memo-start-date"
 
 /**
- * CAL_STATIC_CAPABILITY_ALARM_DESCRIPTION:
+ * E_CAL_STATIC_CAPABILITY_ALARM_DESCRIPTION:
  *
  * Flag indicating that the backend supports alarm description
  *
  * Since: 3.8
  */
-#define CAL_STATIC_CAPABILITY_ALARM_DESCRIPTION                "alarm-description"
+#define E_CAL_STATIC_CAPABILITY_ALARM_DESCRIPTION      "alarm-description"
 
 /**
- * CAL_STATIC_CAPABILITY_NO_ALARM_AFTER_START:
+ * E_CAL_STATIC_CAPABILITY_NO_ALARM_AFTER_START:
  *
  * Flag indicating that the backend does not support alarm after start the event
  *
  * Since: 3.8
  */
-#define CAL_STATIC_CAPABILITY_NO_ALARM_AFTER_START     "no-alarm-after-start"
+#define E_CAL_STATIC_CAPABILITY_NO_ALARM_AFTER_START   "no-alarm-after-start"
 
 /**
- * CAL_STATIC_CAPABILITY_BULK_ADDS:
+ * E_CAL_STATIC_CAPABILITY_BULK_ADDS:
  *
  * Flag indicating that the backend supports bulk additions.
  *
  * Since: 3.6
  */
-#define CAL_STATIC_CAPABILITY_BULK_ADDS                        "bulk-adds"
+#define E_CAL_STATIC_CAPABILITY_BULK_ADDS              "bulk-adds"
 
 /**
- * CAL_STATIC_CAPABILITY_BULK_MODIFIES:
+ * E_CAL_STATIC_CAPABILITY_BULK_MODIFIES:
  *
  * Flag indicating that the backend supports bulk modifications.
  *
  * Since: 3.6
  */
-#define CAL_STATIC_CAPABILITY_BULK_MODIFIES            "bulk-modifies"
+#define E_CAL_STATIC_CAPABILITY_BULK_MODIFIES          "bulk-modifies"
 
 /**
- * CAL_STATIC_CAPABILITY_BULK_REMOVES:
+ * E_CAL_STATIC_CAPABILITY_BULK_REMOVES:
  *
  * Flag indicating that the backend supports bulk removals.
  *
  * Since: 3.6
  */
-#define CAL_STATIC_CAPABILITY_BULK_REMOVES             "bulk-removes"
+#define E_CAL_STATIC_CAPABILITY_BULK_REMOVES           "bulk-removes"
 
 /**
- * CAL_STATIC_CAPABILITY_REMOVE_ONLY_THIS:
+ * E_CAL_STATIC_CAPABILITY_REMOVE_ONLY_THIS:
  *
  * FIXME: Document me.
  *
  * Since: 3.2
  **/
-#define CAL_STATIC_CAPABILITY_REMOVE_ONLY_THIS         "remove-only-this"
+#define E_CAL_STATIC_CAPABILITY_REMOVE_ONLY_THIS       "remove-only-this"
 
-#define CAL_STATIC_CAPABILITY_ONE_ALARM_ONLY           "one-alarm-only"
-#define CAL_STATIC_CAPABILITY_ORGANIZER_MUST_ATTEND    "organizer-must-attend"
-#define CAL_STATIC_CAPABILITY_ORGANIZER_NOT_EMAIL_ADDRESS      "organizer-not-email-address"
-#define CAL_STATIC_CAPABILITY_REMOVE_ALARMS            "remove-alarms"
+#define E_CAL_STATIC_CAPABILITY_ONE_ALARM_ONLY         "one-alarm-only"
+#define E_CAL_STATIC_CAPABILITY_ORGANIZER_MUST_ATTEND  "organizer-must-attend"
+#define E_CAL_STATIC_CAPABILITY_ORGANIZER_NOT_EMAIL_ADDRESS    "organizer-not-email-address"
+#define E_CAL_STATIC_CAPABILITY_REMOVE_ALARMS          "remove-alarms"
 
 /**
- * CAL_STATIC_CAPABILITY_CREATE_MESSAGES:
+ * E_CAL_STATIC_CAPABILITY_CREATE_MESSAGES:
  *
  * Since: 2.26
  **/
-#define CAL_STATIC_CAPABILITY_CREATE_MESSAGES          "create-messages"
-
-#define CAL_STATIC_CAPABILITY_SAVE_SCHEDULES           "save-schedules"
-#define CAL_STATIC_CAPABILITY_NO_CONV_TO_ASSIGN_TASK   "no-conv-to-assign-task"
-#define CAL_STATIC_CAPABILITY_NO_CONV_TO_RECUR         "no-conv-to-recur"
-#define CAL_STATIC_CAPABILITY_NO_GEN_OPTIONS           "no-general-options"
-#define CAL_STATIC_CAPABILITY_REQ_SEND_OPTIONS         "require-send-options"
-#define CAL_STATIC_CAPABILITY_RECURRENCES_NO_MASTER    "recurrences-no-master-object"
-#define CAL_STATIC_CAPABILITY_ORGANIZER_MUST_ACCEPT    "organizer-must-accept"
-#define CAL_STATIC_CAPABILITY_DELEGATE_SUPPORTED       "delegate-support"
-#define CAL_STATIC_CAPABILITY_NO_ORGANIZER             "no-organizer"
-#define CAL_STATIC_CAPABILITY_DELEGATE_TO_MANY         "delegate-to-many"
-#define CAL_STATIC_CAPABILITY_HAS_UNACCEPTED_MEETING   "has-unaccepted-meeting"
+#define E_CAL_STATIC_CAPABILITY_CREATE_MESSAGES                "create-messages"
+
+#define E_CAL_STATIC_CAPABILITY_SAVE_SCHEDULES         "save-schedules"
+#define E_CAL_STATIC_CAPABILITY_NO_CONV_TO_ASSIGN_TASK "no-conv-to-assign-task"
+#define E_CAL_STATIC_CAPABILITY_NO_CONV_TO_RECUR       "no-conv-to-recur"
+#define E_CAL_STATIC_CAPABILITY_NO_GEN_OPTIONS         "no-general-options"
+#define E_CAL_STATIC_CAPABILITY_REQ_SEND_OPTIONS       "require-send-options"
+#define E_CAL_STATIC_CAPABILITY_RECURRENCES_NO_MASTER  "recurrences-no-master-object"
+#define E_CAL_STATIC_CAPABILITY_ORGANIZER_MUST_ACCEPT  "organizer-must-accept"
+#define E_CAL_STATIC_CAPABILITY_DELEGATE_SUPPORTED     "delegate-support"
+#define E_CAL_STATIC_CAPABILITY_NO_ORGANIZER           "no-organizer"
+#define E_CAL_STATIC_CAPABILITY_DELEGATE_TO_MANY       "delegate-to-many"
+#define E_CAL_STATIC_CAPABILITY_HAS_UNACCEPTED_MEETING "has-unaccepted-meeting"
 
 /**
- * CAL_STATIC_CAPABILITY_REFRESH_SUPPORTED:
+ * E_CAL_STATIC_CAPABILITY_REFRESH_SUPPORTED:
  *
  * Since: 2.30
  **/
-#define CAL_STATIC_CAPABILITY_REFRESH_SUPPORTED                "refresh-supported"
+#define E_CAL_STATIC_CAPABILITY_REFRESH_SUPPORTED      "refresh-supported"
 
 /**
- * CAL_STATIC_CAPABILITY_ALL_DAY_EVENT_AS_TIME:
+ * E_CAL_STATIC_CAPABILITY_ALL_DAY_EVENT_AS_TIME:
  *
  * Let the client know that it should store All Day event times as time
  * with a time zone, rather than as a date.
  *
  * Since: 3.18
  **/
-#define CAL_STATIC_CAPABILITY_ALL_DAY_EVENT_AS_TIME    "all-day-event-as-time"
+#define E_CAL_STATIC_CAPABILITY_ALL_DAY_EVENT_AS_TIME  "all-day-event-as-time"
 
 /**
- * CAL_STATIC_CAPABILITY_TASK_DATE_ONLY:
+ * E_CAL_STATIC_CAPABILITY_TASK_DATE_ONLY:
  *
  * Let the client know that the Task Start date, Due date and Completed date
  * can be entered only as dates. When the capability is not set, then these
@@ -225,37 +225,37 @@ gboolean  e_cal_util_event_dates_match    (icalcomponent *icalcomp1,
  *
  * Since: 3.24
  **/
-#define CAL_STATIC_CAPABILITY_TASK_DATE_ONLY           "task-date-only"
+#define E_CAL_STATIC_CAPABILITY_TASK_DATE_ONLY         "task-date-only"
 
 /**
- * CAL_STATIC_CAPABILITY_TASK_CAN_RECUR:
+ * E_CAL_STATIC_CAPABILITY_TASK_CAN_RECUR:
  *
  * When the capability is set, the client can store and provide recurring
  * tasks, otherwise it cannot.
  *
  * Since: 3.30
  **/
-#define CAL_STATIC_CAPABILITY_TASK_CAN_RECUR           "task-can-recur"
+#define E_CAL_STATIC_CAPABILITY_TASK_CAN_RECUR         "task-can-recur"
 
 /**
- * CAL_STATIC_CAPABILITY_TASK_NO_ALARM:
+ * E_CAL_STATIC_CAPABILITY_TASK_NO_ALARM:
  *
  * When the capability is set, the client cannot store reminders
  * on tasks, otherwise it can.
  *
  * Since: 3.30
  **/
-#define CAL_STATIC_CAPABILITY_TASK_NO_ALARM            "task-no-alarm"
+#define E_CAL_STATIC_CAPABILITY_TASK_NO_ALARM          "task-no-alarm"
 
 /**
- * CAL_STATIC_CAPABILITY_COMPONENT_COLOR:
+ * E_CAL_STATIC_CAPABILITY_COMPONENT_COLOR:
  *
  * When the capability is set, the client supports storing color
  * for individual components.
  *
  * Since: 3.30
  **/
-#define CAL_STATIC_CAPABILITY_COMPONENT_COLOR          "component-color"
+#define E_CAL_STATIC_CAPABILITY_COMPONENT_COLOR                "component-color"
 
 /* Recurrent events. Management for instances */
 icalcomponent *        e_cal_util_construct_instance   (icalcomponent *icalcomp,
diff --git a/src/calendar/libecal/e-reminder-watcher.c b/src/calendar/libecal/e-reminder-watcher.c
index 7db020c51..d3ba4517b 100644
--- a/src/calendar/libecal/e-reminder-watcher.c
+++ b/src/calendar/libecal/e-reminder-watcher.c
@@ -2417,7 +2417,7 @@ e_reminder_watcher_get_alarm_summary (EReminderWatcher *watcher,
 
                client = e_reminder_watcher_ref_opened_client (watcher, rd->source_uid);
 
-               if (client && e_client_check_capability (E_CLIENT (client), 
CAL_STATIC_CAPABILITY_ALARM_DESCRIPTION)) {
+               if (client && e_client_check_capability (E_CLIENT (client), 
E_CAL_STATIC_CAPABILITY_ALARM_DESCRIPTION)) {
                        e_cal_component_alarm_get_description (alarm, &alarm_text);
                        if (!alarm_text.value || !*alarm_text.value)
                                alarm_text.value = NULL;
diff --git a/src/calendar/libedata-cal/e-cal-meta-backend.c b/src/calendar/libedata-cal/e-cal-meta-backend.c
index fbad412d8..4ead1c771 100644
--- a/src/calendar/libedata-cal/e-cal-meta-backend.c
+++ b/src/calendar/libedata-cal/e-cal-meta-backend.c
@@ -1465,7 +1465,7 @@ ecmb_get_free_busy_sync (ECalBackendSync *sync_backend,
        if (!users)
                return;
 
-       cal_email_address = e_cal_backend_get_backend_property (E_CAL_BACKEND (meta_backend), 
CAL_BACKEND_PROPERTY_CAL_EMAIL_ADDRESS);
+       cal_email_address = e_cal_backend_get_backend_property (E_CAL_BACKEND (meta_backend), 
E_CAL_BACKEND_PROPERTY_CAL_EMAIL_ADDRESS);
        if (!cal_email_address)
                return;
 
@@ -2778,7 +2778,7 @@ ecmb_get_backend_property (ECalBackend *cal_backend,
        g_return_val_if_fail (E_IS_CAL_META_BACKEND (cal_backend), NULL);
        g_return_val_if_fail (prop_name != NULL, NULL);
 
-       if (g_str_equal (prop_name, CAL_BACKEND_PROPERTY_REVISION)) {
+       if (g_str_equal (prop_name, E_CAL_BACKEND_PROPERTY_REVISION)) {
                ECalCache *cal_cache;
                gchar *revision = NULL;
 
@@ -2791,7 +2791,7 @@ ecmb_get_backend_property (ECalBackend *cal_backend,
                }
 
                return revision;
-       } else if (g_str_equal (prop_name, CAL_BACKEND_PROPERTY_DEFAULT_OBJECT)) {
+       } else if (g_str_equal (prop_name, E_CAL_BACKEND_PROPERTY_DEFAULT_OBJECT)) {
                ECalComponent *comp;
                gchar *prop_value;
 
@@ -3451,10 +3451,10 @@ e_cal_meta_backend_get_capabilities (ECalMetaBackend *meta_backend)
 {
        g_return_val_if_fail (E_IS_CAL_META_BACKEND (meta_backend), NULL);
 
-       return CAL_STATIC_CAPABILITY_REFRESH_SUPPORTED ","
-               CAL_STATIC_CAPABILITY_BULK_ADDS ","
-               CAL_STATIC_CAPABILITY_BULK_MODIFIES ","
-               CAL_STATIC_CAPABILITY_BULK_REMOVES;
+       return E_CAL_STATIC_CAPABILITY_REFRESH_SUPPORTED ","
+               E_CAL_STATIC_CAPABILITY_BULK_ADDS ","
+               E_CAL_STATIC_CAPABILITY_BULK_MODIFIES ","
+               E_CAL_STATIC_CAPABILITY_BULK_REMOVES;
 }
 
 /**
@@ -3633,7 +3633,7 @@ ecmb_cache_revision_changed_cb (ECache *cache,
        revision = e_cache_dup_revision (cache);
        if (revision) {
                e_cal_backend_notify_property_changed (E_CAL_BACKEND (meta_backend),
-                       CAL_BACKEND_PROPERTY_REVISION, revision);
+                       E_CAL_BACKEND_PROPERTY_REVISION, revision);
                g_free (revision);
        }
 }
diff --git a/src/calendar/libedata-cal/e-data-cal.c b/src/calendar/libedata-cal/e-data-cal.c
index 270588df7..93fdc193c 100644
--- a/src/calendar/libedata-cal/e-data-cal.c
+++ b/src/calendar/libedata-cal/e-data-cal.c
@@ -2461,13 +2461,13 @@ e_data_cal_report_backend_property_changed (EDataCal *cal,
        if (g_str_equal (prop_name, CLIENT_BACKEND_PROPERTY_REVISION))
                e_dbus_calendar_set_revision (dbus_interface, prop_value);
 
-       if (g_str_equal (prop_name, CAL_BACKEND_PROPERTY_CAL_EMAIL_ADDRESS))
+       if (g_str_equal (prop_name, E_CAL_BACKEND_PROPERTY_CAL_EMAIL_ADDRESS))
                e_dbus_calendar_set_cal_email_address (dbus_interface, prop_value);
 
-       if (g_str_equal (prop_name, CAL_BACKEND_PROPERTY_ALARM_EMAIL_ADDRESS))
+       if (g_str_equal (prop_name, E_CAL_BACKEND_PROPERTY_ALARM_EMAIL_ADDRESS))
                e_dbus_calendar_set_alarm_email_address (dbus_interface, prop_value);
 
-       if (g_str_equal (prop_name, CAL_BACKEND_PROPERTY_DEFAULT_OBJECT))
+       if (g_str_equal (prop_name, E_CAL_BACKEND_PROPERTY_DEFAULT_OBJECT))
                e_dbus_calendar_set_default_object (dbus_interface, prop_value);
 
        /* Disregard anything else. */
@@ -2651,19 +2651,19 @@ data_cal_constructed (GObject *object)
                cal, prop_name, prop_value);
        g_free (prop_value);
 
-       prop_name = CAL_BACKEND_PROPERTY_CAL_EMAIL_ADDRESS;
+       prop_name = E_CAL_BACKEND_PROPERTY_CAL_EMAIL_ADDRESS;
        prop_value = e_cal_backend_get_backend_property (backend, prop_name);
        e_data_cal_report_backend_property_changed (
                cal, prop_name, prop_value);
        g_free (prop_value);
 
-       prop_name = CAL_BACKEND_PROPERTY_ALARM_EMAIL_ADDRESS;
+       prop_name = E_CAL_BACKEND_PROPERTY_ALARM_EMAIL_ADDRESS;
        prop_value = e_cal_backend_get_backend_property (backend, prop_name);
        e_data_cal_report_backend_property_changed (
                cal, prop_name, prop_value);
        g_free (prop_value);
 
-       prop_name = CAL_BACKEND_PROPERTY_DEFAULT_OBJECT;
+       prop_name = E_CAL_BACKEND_PROPERTY_DEFAULT_OBJECT;
        prop_value = e_cal_backend_get_backend_property (backend, prop_name);
        e_data_cal_report_backend_property_changed (
                cal, prop_name, prop_value);
diff --git a/src/services/evolution-alarm-notify/e-alarm-notify.c 
b/src/services/evolution-alarm-notify/e-alarm-notify.c
index 96a8f2993..4f5f6101b 100644
--- a/src/services/evolution-alarm-notify/e-alarm-notify.c
+++ b/src/services/evolution-alarm-notify/e-alarm-notify.c
@@ -283,7 +283,7 @@ e_alarm_notify_email (EAlarmNotify *an,
        g_return_val_if_fail (alarm != NULL, FALSE);
 
        client = e_reminder_watcher_ref_opened_client (an->priv->watcher, rd->source_uid);
-       if (client && !e_client_check_capability (E_CLIENT (client), CAL_STATIC_CAPABILITY_NO_EMAIL_ALARMS)) {
+       if (client && !e_client_check_capability (E_CLIENT (client), 
E_CAL_STATIC_CAPABILITY_NO_EMAIL_ALARMS)) {
                g_object_unref (client);
                return FALSE;
        }
diff --git a/tests/libedata-cal/test-cal-meta-backend.c b/tests/libedata-cal/test-cal-meta-backend.c
index edfe7e1a8..8065b6b9d 100644
--- a/tests/libedata-cal/test-cal-meta-backend.c
+++ b/tests/libedata-cal/test-cal-meta-backend.c
@@ -262,9 +262,9 @@ e_cal_meta_backend_test_get_backend_property (ECalBackend *cal_backend,
        if (g_str_equal (prop_name, CLIENT_BACKEND_PROPERTY_CAPABILITIES)) {
                return g_strjoin (",",
                        e_cal_meta_backend_get_capabilities (E_CAL_META_BACKEND (cal_backend)),
-                       CAL_STATIC_CAPABILITY_ALARM_DESCRIPTION,
+                       E_CAL_STATIC_CAPABILITY_ALARM_DESCRIPTION,
                        NULL);
-       } else if (g_str_equal (prop_name, CAL_BACKEND_PROPERTY_CAL_EMAIL_ADDRESS)) {
+       } else if (g_str_equal (prop_name, E_CAL_BACKEND_PROPERTY_CAL_EMAIL_ADDRESS)) {
                return g_strdup ("user@no.where");
        }
 


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/calendar/libecal/e-cal-client.c b/src/calendar/libecal/e-cal-client.c
index 6ad0923bc..441a93d44 100644
--- a/src/calendar/libecal/e-cal-client.c
+++ b/src/calendar/libecal/e-cal-client.c
@@ -230,11 +230,11 @@ free_zone_cb (gpointer zone)
 
 /*
  * Well-known calendar backend properties:
  * @CAL_BACKEND_PROPERTY_CAL_EMAIL_ADDRESS: Contains default calendar's email
  *   address suggested by the backend.
  * @CAL_BACKEND_PROPERTY_ALARM_EMAIL_ADDRESS: Contains default alarm email
  *   address suggested by the backend.
  * @CAL_BACKEND_PROPERTY_DEFAULT_OBJECT: Contains iCal component string
  *   of an #icalcomponent with the default values for properties needed.
  *   Preferred way of retrieving this property is by
  *   calling e_cal_client_get_default_object().
@@ -561,7 +561,7 @@ cal_client_dbus_proxy_property_changed (EClient *client,
        g_return_if_fail (property_name != NULL);
 
        if (g_str_equal (property_name, "alarm-email-address")) {
-               backend_prop_name = CAL_BACKEND_PROPERTY_ALARM_EMAIL_ADDRESS;
+               backend_prop_name = E_CAL_BACKEND_PROPERTY_ALARM_EMAIL_ADDRESS;
        }
 
        if (g_str_equal (property_name, "cache-dir")) {
@@ -569,7 +569,7 @@ cal_client_dbus_proxy_property_changed (EClient *client,
        }
 
        if (g_str_equal (property_name, "cal-email-address")) {
-               backend_prop_name = CAL_BACKEND_PROPERTY_CAL_EMAIL_ADDRESS;
+               backend_prop_name = E_CAL_BACKEND_PROPERTY_CAL_EMAIL_ADDRESS;
        }
 
        if (g_str_equal (property_name, "capabilities")) {
@@ -587,7 +587,7 @@ cal_client_dbus_proxy_property_changed (EClient *client,
        }
 
        if (g_str_equal (property_name, "default-object")) {
-               backend_prop_name = CAL_BACKEND_PROPERTY_DEFAULT_OBJECT;
+               backend_prop_name = E_CAL_BACKEND_PROPERTY_DEFAULT_OBJECT;
        }
 
        if (g_str_equal (property_name, "online")) {
@@ -1017,17 +1017,17 @@ cal_client_get_backend_property_sync (EClient *client,
                return TRUE;
        }
 
-       if (g_str_equal (prop_name, CAL_BACKEND_PROPERTY_ALARM_EMAIL_ADDRESS)) {
+       if (g_str_equal (prop_name, E_CAL_BACKEND_PROPERTY_ALARM_EMAIL_ADDRESS)) {
                *prop_value = e_dbus_calendar_dup_alarm_email_address (dbus_proxy);
                return TRUE;
        }
 
-       if (g_str_equal (prop_name, CAL_BACKEND_PROPERTY_CAL_EMAIL_ADDRESS)) {
+       if (g_str_equal (prop_name, E_CAL_BACKEND_PROPERTY_CAL_EMAIL_ADDRESS)) {
                *prop_value = e_dbus_calendar_dup_cal_email_address (dbus_proxy);
                return TRUE;
        }
 
-       if (g_str_equal (prop_name, CAL_BACKEND_PROPERTY_DEFAULT_OBJECT)) {
+       if (g_str_equal (prop_name, E_CAL_BACKEND_PROPERTY_DEFAULT_OBJECT)) {
                *prop_value = e_dbus_calendar_dup_default_object (dbus_proxy);
                return TRUE;
        }
@@ -2075,7 +2075,7 @@ e_cal_client_check_one_alarm_only (ECalClient *client)
 
        return e_client_check_capability (
                E_CLIENT (client),
-               CAL_STATIC_CAPABILITY_ONE_ALARM_ONLY);
+               E_CAL_STATIC_CAPABILITY_ONE_ALARM_ONLY);
 }
 
 /**
@@ -2095,7 +2095,7 @@ e_cal_client_check_save_schedules (ECalClient *client)
 
        return e_client_check_capability (
                E_CLIENT (client),
-               CAL_STATIC_CAPABILITY_SAVE_SCHEDULES);
+               E_CAL_STATIC_CAPABILITY_SAVE_SCHEDULES);
 }
 
 /**
@@ -2116,7 +2116,7 @@ e_cal_client_check_organizer_must_attend (ECalClient *client)
 
        return e_client_check_capability (
                E_CLIENT (client),
-               CAL_STATIC_CAPABILITY_ORGANIZER_MUST_ATTEND);
+               E_CAL_STATIC_CAPABILITY_ORGANIZER_MUST_ATTEND);
 }
 
 /**
@@ -2138,7 +2138,7 @@ e_cal_client_check_organizer_must_accept (ECalClient *client)
 
        return e_client_check_capability (
                E_CLIENT (client),
-               CAL_STATIC_CAPABILITY_ORGANIZER_MUST_ACCEPT);
+               E_CAL_STATIC_CAPABILITY_ORGANIZER_MUST_ACCEPT);
 }
 
 /**
@@ -2159,7 +2159,7 @@ e_cal_client_check_recurrences_no_master (ECalClient *client)
 
        return e_client_check_capability (
                E_CLIENT (client),
-               CAL_STATIC_CAPABILITY_RECURRENCES_NO_MASTER);
+               E_CAL_STATIC_CAPABILITY_RECURRENCES_NO_MASTER);
 }
 
 /**
@@ -3165,7 +3165,7 @@ e_cal_client_generate_instances_for_object (ECalClient *client,
 
        /* If the backend stores it as individual instances and does not
         * have a master object - do not expand */
-       if (is_single_instance || e_client_check_capability (E_CLIENT (client), 
CAL_STATIC_CAPABILITY_RECURRENCES_NO_MASTER)) {
+       if (is_single_instance || e_client_check_capability (E_CLIENT (client), 
E_CAL_STATIC_CAPABILITY_RECURRENCES_NO_MASTER)) {
                /* return the same instance */
                (* cb)  (comp,
                        icaltime_as_timet_with_zone (
@@ -3274,7 +3274,7 @@ e_cal_client_generate_instances_for_object_sync (ECalClient *client,
 
        /* If the backend stores it as individual instances and does not
         * have a master object - do not expand */
-       if (is_single_instance || e_client_check_capability (E_CLIENT (client), 
CAL_STATIC_CAPABILITY_RECURRENCES_NO_MASTER)) {
+       if (is_single_instance || e_client_check_capability (E_CLIENT (client), 
E_CAL_STATIC_CAPABILITY_RECURRENCES_NO_MASTER)) {
                /* return the same instance */
                (* cb)  (comp,
@@ -230,11 +230,11 @@ free_zone_cb (gpointer zone)
 /*
  * Well-known calendar backend properties:
- * @CAL_BACKEND_PROPERTY_CAL_EMAIL_ADDRESS: Contains default calendar's email
+ * @E_CAL_BACKEND_PROPERTY_CAL_EMAIL_ADDRESS: Contains default calendar's email
  *   address suggested by the backend.
@@ -230,11 +230,11 @@ free_zone_cb (gpointer zone)
  *   address suggested by the backend.
- * @CAL_BACKEND_PROPERTY_ALARM_EMAIL_ADDRESS: Contains default alarm email
+ * @E_CAL_BACKEND_PROPERTY_ALARM_EMAIL_ADDRESS: Contains default alarm email
  *   address suggested by the backend.
@@ -230,11 +230,11 @@ free_zone_cb (gpointer zone)
  *   address suggested by the backend.
- * @CAL_BACKEND_PROPERTY_DEFAULT_OBJECT: Contains iCal component string
+ * @E_CAL_BACKEND_PROPERTY_DEFAULT_OBJECT: Contains iCal component string
  *   of an #icalcomponent with the default values for properties needed.
  *   Preferred way of retrieving this property is by
                        icaltime_as_timet_with_zone (